@@ -5,6 +5,7 @@ Django Rest Framework utility classes
 Anything in this package is used along with the Django Rest Framework
 to provide for our use cases within our application.
 """
+import logging
 import time
 import django
 from django.conf import settings
@@ -20,10 +21,8 @@ from rest_framework.permissions import BasePermission
 from rest_framework.response import Response
 from rest_framework.utils.urls import replace_query_param
 from rest_framework_simplejwt.authentication import JWTAuthentication
-
 from rest_framework.relations import HyperlinkedRelatedField, HyperlinkedIdentityField
 from rest_framework.serializers import HyperlinkedModelSerializer
-
 from gramedia.common.http import LinkHeaderField, LinkHeaderRel
 from gramedia.django.signalling import BasicRpcClient
 from gramedia.django.utils.helpers import get_user_agent
@@ -31,12 +30,13 @@ from rest_framework_simplejwt.exceptions import AuthenticationFailed
 from rest_framework_simplejwt.exceptions import InvalidToken
 from rest_framework_simplejwt.settings import api_settings
 
-
 if django.VERSION >= (4, 0):
     from django.utils.translation import gettext_lazy as _
 else:
     from django.utils.translation import ugettext_lazy as _
 
+logger = logging.getLogger('DRFCommon')
+
 class LinkHeaderPagination(pagination.PageNumberPagination):
     """ Replaces the default pagination classes, provided by DRF, with one
     that returns pagination data as part of the HTTP Link header.
@@ -130,6 +130,7 @@ class SoftDeletableListViewMixin:
     If the 'include_inactive=true', parameter is passed in the query string,
     then all models (regardless of 'is_active' attribute), will be returned.
     """
+
     def get_queryset(self):
         if convert_env_boolean(self.request.query_params.get('include_inactive', '')):
             return self.queryset
@@ -141,6 +142,7 @@ class IsAuthenticatedOrOptions(BasePermission):
     """ Allows access only to authenticated users, unless the request is
     for the http OPTIONS method, then the user is directly allowed.
     """
+
     def has_permission(self, request, view):
         if request.method == 'OPTIONS':
             return True
@@ -173,6 +175,7 @@ def create_summary_serializer(serializer_cls):
     :param serializer_cls:
     :return:
     """
+
     class SummarySerializer(serializer_cls):
         class Meta(serializer_cls.Meta):
             fields = getattr(
@@ -180,6 +183,7 @@ def create_summary_serializer(serializer_cls):
                 'summary_fields',
                 ('href', 'name')
             )
+
     return SummarySerializer
 
 
@@ -321,7 +325,7 @@ class JWTNusantaraAuthentication(JWTAuthentication):
         if get_user_agent(self.request).device_name == 'Bhisma POS':
             IAM_POS_USER_RPC = f"{settings.CLUSTER_PREFIX}iam_pos_user_rpc"  # iam_user_rpc
             publish = BasicRpcClient(routing=IAM_POS_USER_RPC)
-
+            logger.info(f'Calling RPC Client {IAM_POS_USER_RPC}')
             rpc_response = publish.call(
                 message={
                     "email": user.email
@@ -330,27 +334,21 @@ class JWTNusantaraAuthentication(JWTAuthentication):
                 entity_type='pos_user_rpc',
                 site=site
             )
+            logger.info(f'End call RPC Client {IAM_POS_USER_RPC}')
+            logger.debug(rpc_response)
 
-            step = 0
-            user = None
-            while step <= 10:
-                step = step + 1
-                data = rpc_response.get('data')
 
-                if not data.get('is_staff', False):
-                    raise PermissionDenied(_('Unauthorized employee access'), code='unauthorized_employee')
+            data = rpc_response.get('data')
 
-                if not data.get('can_use_pos', False):
-                    raise PermissionDenied(_('Unauthorized POS access'), code='unauthorized_pos_user')
+            if not data.get('is_staff', False):
+                raise PermissionDenied(_('Unauthorized employee access'), code='unauthorized_employee')
 
-                warehouse = self.request.META.get('HTTP_WAREHOUSE', '')
-                if warehouse not in data.get('warehouses', []):
-                    raise PermissionDenied(_('Unauthorized POS warehouse'), code='unauthorized_pos_warehouse')
+            if not data.get('can_use_pos', False):
+                raise PermissionDenied(_('Unauthorized POS access'), code='unauthorized_pos_user')
 
-                time.sleep(0.25)
-
-            if not user:
-                raise AuthenticationFailed(_('User not found'), code='user_not_found')
+            warehouse = self.request.META.get('HTTP_WAREHOUSE', '')
+            if warehouse not in data.get('warehouses', []):
+                raise PermissionDenied(_('Unauthorized POS warehouse'), code='unauthorized_pos_warehouse')
 
         return user
 
@@ -359,7 +357,7 @@ def is_normal_user(request):
     if not request.user:
         return True
 
-    if not(request.user.is_staff or request.user.is_superuser):
+    if not (request.user.is_staff or request.user.is_superuser):
         return True
 
 
@@ -370,7 +368,8 @@ def get_entity_href_serializer(model_class, meta_extra_kwargs=None, *init_args,
         class Meta:
             model = model_class
             fields = ('href', 'name',)
-            extra_kwargs = meta_extra_kwargs if meta_extra_kwargs is not None else {'href': {'lookup_field': 'slug', }, }
+            extra_kwargs = meta_extra_kwargs if meta_extra_kwargs is not None else {
+                'href': {'lookup_field': 'slug', }, }
 
     return EntityHrefSerializer(*init_args, **init_kwargs)
 
